Output formats
=======================

.. automodule:: cruiseplan.output
   :members:

Note that the current set of outputs were each designed for a specific purpose.

cruiseplan.output.csv_generator module
-----------------------------------------

.. automodule:: cruiseplan.output.csv_generator
   :members:
   :undoc-members:
   :show-inheritance:

cruiseplan.output.html_generator module
------------------------------------------

.. automodule:: cruiseplan.output.html_generator
   :members:
   :undoc-members:
   :show-inheritance:

cruiseplan.output.kml_generator module
-----------------------------------------

.. automodule:: cruiseplan.output.kml_generator
   :members:
   :undoc-members:
   :show-inheritance:

cruiseplan.output.latex_generator module
-------------------------------------------

.. automodule:: cruiseplan.output.latex_generator
   :members:
   :undoc-members:
   :show-inheritance:
   :no-index:


cruiseplan.output.map_generator module
-----------------------------------------

.. automodule:: cruiseplan.output.map_generator
   :members:
   :undoc-members:
   :show-inheritance:

cruiseplan.output.netcdf_generator module
--------------------------------------------

.. automodule:: cruiseplan.output.netcdf_generator
   :members:
   :undoc-members:
   :show-inheritance:
